"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mintV2 = void 0;
const mpl_essentials_1 = require("@metaplex-foundation/mpl-essentials");
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const umi_1 = require("@metaplex-foundation/umi");
const mintV2_1 = require("./generated/instructions/mintV2");
const guards_1 = require("./guards");
const hooked_1 = require("./hooked");
function mintV2(context, input) {
    const { mintArgs = {}, group = (0, umi_1.none)(), ...rest } = input;
    const program = context.programs.get('mplCandyGuard');
    const mintContext = {
        minter: input.minter ?? context.identity,
        payer: input.payer ?? context.payer,
        mint: (0, umi_1.publicKey)(input.nftMint),
        candyMachine: input.candyMachine,
        candyGuard: input.candyGuard ??
            (0, hooked_1.findCandyGuardPda)(context, { base: input.candyMachine }),
    };
    const { data, remainingAccounts } = (0, guards_1.parseMintArgs)(context, program, mintContext, mintArgs);
    const prefix = context.serializer.u32().serialize(data.length);
    const defaultTokenRecord = (0, mpl_token_metadata_1.isProgrammable)(input.tokenStandard ?? mpl_token_metadata_1.TokenStandard.NonFungible)
        ? (0, mpl_token_metadata_1.findTokenRecordPda)(context, {
            mint: (0, umi_1.publicKey)(input.nftMint),
            token: (0, mpl_essentials_1.findAssociatedTokenPda)(context, {
                mint: (0, umi_1.publicKey)(input.nftMint),
                owner: (0, umi_1.publicKey)(input.minter ?? context.identity),
            }),
        })
        : undefined;
    const ix = (0, mintV2_1.mintV2)(context, {
        ...rest,
        tokenRecord: input.tokenRecord ?? defaultTokenRecord,
        mintArgs: (0, umi_1.mergeBytes)([prefix, data]),
        group,
    }).items[0];
    const [keys, signers] = (0, guards_1.parseGuardRemainingAccounts)(remainingAccounts);
    ix.instruction.keys.push(...keys);
    ix.signers.push(...signers);
    return (0, umi_1.transactionBuilder)([ix]);
}
exports.mintV2 = mintV2;
//# sourceMappingURL=mintV2.js.map